@@ -1,10 +1,10 @@
 """
-CryspyEditor
+CrysPyEditor
 ======
 
 """
 name = "cryspy_editor"
-from .main_window import main_w
+from cryspy_editor.main_window import main_w
 
 
 if __name__ == "__main__":
