@@ -55,6 +55,7 @@ def dock_rhochi(obj: RhoChi, thread: QtCore.QThread):
     docks = []
     flag_crystals = len(crystals) != 0
     flag_experiments = len(experiments) != 0
+    flag_diffrn = any([isinstance(exp, Diffrn) for exp in experiments])
 
     for experiment in experiments:
         if isinstance(experiment, Pd):
@@ -147,6 +148,16 @@ def dock_rhochi(obj: RhoChi, thread: QtCore.QThread):
         qlabel.setSizePolicy(QtWidgets.QSizePolicy.Expanding,
                              QtWidgets.QSizePolicy.Expanding)
         layout_actions.addWidget(qlabel)
+    if (flag_diffrn & flag_crystals):
+        cb_1 = QtWidgets.QPushButton("Estimate F_M")
+        # cb_1.setStyleSheet("background-color:red;")
+        cb_1.setSizePolicy(QtWidgets.QSizePolicy.Expanding,
+                           QtWidgets.QSizePolicy.Expanding)
+        cb_1.setMinimumHeight(ICON_SIZE)
+        cb_1.setStyleSheet("background-color:#FAD;")
+        cb_1.clicked.connect(lambda: run_function(
+            obj.estimate_f_mag_for_diffrn, (), thread))
+        layout_actions.addWidget(cb_1)
     layout_actions.addStretch(1)
 
     widget_actions = QtWidgets.QWidget()
